Learn R Programming

opencastR (version 0.1.3)

oc_info_me: Query Opencast current user

Description

Returns information on the logged in user.

Usage

oc_info_me()

Arguments

Value

A list containing the information about the current user.

Details

This function expects the hostname, username and password to be set as environment variables.

Examples

Run this code
# NOT RUN {
Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org")
Sys.setenv(OPENCAST_USERNAME = "admin")
Sys.setenv(OPENCAST_PASSWORD = "opencast")

oc_info_me()
# }

Run the code above in your browser using DataLab