Learn R Programming

opencastR (version 0.1.3)

oc_info_organization: Query Opencast current organization

Description

Returns the current organization.

Usage

oc_info_organization()

Arguments

Value

A list containing the settings for the anonymous role, the name, the admin role and the id.

Details

This function expects the hostname, username and password to be set as environment variables.

Examples

Run this code
# NOT RUN {
Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org")
Sys.setenv(OPENCAST_USERNAME = "admin")
Sys.setenv(OPENCAST_PASSWORD = "opencast")

oc_info_organization()
# }

Run the code above in your browser using DataLab