Whether public distribution urls should be signed.
withacl
Whether the acl metadata should be included in the response.
withmetadata
Whether the metadata catalogs should be included in the response.
withscheduling
Whether the scheduling information should be included in the response.
withpublications
Whether the publication ids and urls should be included in the response.
filter
A comma seperated list of filters to limit the results with. A filter is the filter's name followed by a colon ":" and then the value to filter with so it is the form :.
sort
Sort the results based upon a list of comma seperated sorting criteria. In the comma seperated list each type of sorting is specified as a pair such as: :ASC or :DESC. Adding the suffix ASC or DESC sets the order as ascending or descending order and is mandatory.
limit
The maximum number of results to return for a single request.
offset
The index of the first result to return.
Value
Returns a list of events.
Details
This function expects the hostname, username and password to be set as environment variables.