Learn R Programming

opencastR (version 0.1.3)

oc_series_metadata: Query Opencast for a specific series metadata

Description

Returns a series' metadata of all types or returns a series' metadata collection of the given type when the query string parameter type is specified.

Usage

oc_series_metadata(seriesId = "", type = "")

Arguments

seriesId

The event id

type

The type of metadata to get

Value

Returns a series' metadata of all types or returns a series' metadata collection of the given type when the query string parameter type is specified.

Details

This function expects the hostname, username and password to be set as environment variables.

Examples

Run this code
# NOT RUN {
Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org")
Sys.setenv(OPENCAST_USERNAME = "admin")
Sys.setenv(OPENCAST_PASSWORD = "opencast")

series <- oc_list_series()

oc_series_metadata(series$content$identifier[1])
# }

Run the code above in your browser using DataLab