Learn R Programming

opencastR (version 0.1.3)

print.oc_event: Print result of oc_event()

Description

Print a structured return of the oc_event() function.

Usage

# S3 method for oc_event
print(x, ...)

Arguments

x

The return of the function this print function relates to.

...

Possible further options to the print function.

Value

A structured print of the return by the oc_event() function.

See Also

oc_event

Examples

Run this code
# NOT RUN {
Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org")
Sys.setenv(OPENCAST_USERNAME = "admin")
Sys.setenv(OPENCAST_PASSWORD = "opencast")

events <- oc_list_events()

resp <- oc_event(events$content$identifier[1])

resp
# }

Run the code above in your browser using DataLab