Learn R Programming

opencastR (version 0.1.3)

print.oc_event_publication: Print result of oc_event_publication()

Description

Print a structured return of the oc_event_publication() function.

Usage

# S3 method for oc_event_publication
print(x, ...)

Arguments

x

The return of the function this print function relates to.

...

Possible further options to the print function.

Value

A structured print of the return by the oc_event_publication() function.

See Also

oc_event_publication

Examples

Run this code
# NOT RUN {
Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org")
Sys.setenv(OPENCAST_USERNAME = "admin")
Sys.setenv(OPENCAST_PASSWORD = "opencast")

events <- oc_list_events()
publications <- oc_event_list_publications(events$content$identifier[1])

resp <- oc_event_publication(events$content$identifier[1],
                             publications$content$id[1])

resp
# }

Run the code above in your browser using DataLab