Learn R Programming

opencastR (version 0.1.3)

print.oc_info_me: Print result of oc_info_me()

Description

Print a structured return of the oc_info_me() function.

Usage

# S3 method for oc_info_me
print(x, ...)

Arguments

x

The return of the function this print function relates to.

...

Possible further options to the print function.

Value

A structured print of the return by the oc_info_me() function.

See Also

oc_info_me

Examples

Run this code
# NOT RUN {
Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org")
Sys.setenv(OPENCAST_USERNAME = "admin")
Sys.setenv(OPENCAST_PASSWORD = "opencast")

resp <- oc_info_me()

resp
# }

Run the code above in your browser using DataLab