powered by
Returns information on the logged in user.
oc_info_me()
A list containing the information about the current user.
This function expects the hostname, username and password to be set as environment variables.
# NOT RUN { Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org") Sys.setenv(OPENCAST_USERNAME = "admin") Sys.setenv(OPENCAST_PASSWORD = "opencast") oc_info_me() # }
Run the code above in your browser using DataLab