powered by
Returns the current organization.
oc_info_organization()
A list containing the settings for the anonymous role, the name, the admin role and the id.
This function expects the hostname, username and password to be set as environment variables.
# NOT RUN { Sys.setenv(OPENCAST_HOST = "https://legacy.opencast.org") Sys.setenv(OPENCAST_USERNAME = "admin") Sys.setenv(OPENCAST_PASSWORD = "opencast") oc_info_organization() # }
Run the code above in your browser using DataLab